@@ -1,29 +1,25 @@
 from viset.caltech import Caltech101
 from viset.dataset import Viset
 from viset.show import imshow
+from time import sleep
 
-
-if __name__ == '__main__':
+def main():
   # Create a new viset
   print 'Creating vision dataset for Caltech101 dataset'
   dbfile = Caltech101().export()
   print 'Exporting Caltech101 dataset to redistributable HDF5 file "' + dbfile + '"'
-  
+
   # Import an existing viset 
   print 'Displaying all images in viset (VISion dataSET) "' + dbfile + '"'
-  db = Viset(dbfile)
-  for (im,annotation) in db.read(n_skip=100):
+  db = Viset(dbfile, datastep=100)
+  for (im,annotation) in db['dataset']:
     print 'Image=' + str(annotation['id_img']) + ' Category=' + annotation['category']
-    imshow(im)
-    sleep(0.2)
-
-  for (im,annotation) in db.read(category=['airplanes','Faces'], n_skip=10):
-    print 'Image=' + str(annotation['id_img']) + ' Category=' + annotation['category']
-    imshow(im)
-    sleep(0.2)
+    imshow(im, title=annotation['category'])
 
   # Cleanup cached data (optional)
-  print 'Deleting all cached data in "' + db.cachedir + '"'  
-  db.delete()
+  # db.delete()
+
+if __name__ == '__main__':
+  main()
 
   
