@@ -57,18 +57,10 @@ def main():
   for (im,anno) in db['test']:
     print anno
 
-  print '[test_viset.py]: dataset splits'  
-  db = Viset(dbfile,split='kfold',kfold=3)
-  for (im,anno) in db[1]['train']:
+  print '[test_viset.py]: dataset splits'
+  db = Viset(dbfile,split=None)
+  for (im,anno) in db['dataset']:
     print anno
-  for (im,anno) in db[1]['test']:
-    print anno
-    pass
-
-  #  print '[test_viset.py]: dataset splits'
-  #db = Viset(dbfile,split=None)
-  #for (im,anno) in db['dataset']:
-  #  print anno
 
   
     
