@@ -13,7 +13,7 @@ import time
 import random
 from itertools import imap, islice, count
 
-socket.setdefaulttimeout(10)  # for urlretrieve
+
 
 class AboutTable(tables.IsDescription):
   viset = tables.StringCol(256, pos=1)   
@@ -253,6 +253,7 @@ class Viset(object):
       if not os.path.isfile(filename):
         print 'Retrieving ' + url
         try:
+          socket.setdefaulttimeout(10)  # do not set globally
           urllib.urlretrieve(url, filename)
           im = pylab.imread(filename)
         except:
